You are viewing a plain text version of this content. The canonical link for it is here.
Posted to common-commits@hadoop.apache.org by iw...@apache.org on 2020/09/14 12:58:12 UTC

[hadoop] 02/02: Updated timeline reader to use AuthenticationFilter

This is an automated email from the ASF dual-hosted git repository.

iwasakims pushed a commit to branch branch-2.10
in repository https://gitbox.apache.org/repos/asf/hadoop.git

commit 4885ea61fee6e1da440a9b3cc98a42ffa443f75c
Author: Wangda Tan <wa...@apache.org>
AuthorDate: Thu Mar 8 09:23:45 2018 -0800

    Updated timeline reader to use AuthenticationFilter
    
    Change-Id: I961771589180c1eb377d36c37a79aa23754effbf
    (cherry picked from commit 837338788eb903d0e8bbb1230694782a707891be)
    (cherry picked from commit ea18e70a74e811ffa48c7e18e68510dd37dda63d)
---
 .../TimelineReaderAuthenticationFilterInitializer.java         | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-timelineservice/src/main/java/org/apache/hadoop/yarn/server/timelineservice/reader/security/TimelineReaderAuthenticationFilterInitializer.java b/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-timelineservice/src/main/java/org/apache/hadoop/yarn/server/timelineservice/reader/security/TimelineReaderAuthenticationFilterInitializer.java
index e1c93be..d81e5e8 100644
--- a/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-timelineservice/src/main/java/org/apache/hadoop/yarn/server/timelineservice/reader/security/TimelineReaderAuthenticationFilterInitializer.java
+++ b/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-timelineservice/src/main/java/org/apache/hadoop/yarn/server/timelineservice/reader/security/TimelineReaderAuthenticationFilterInitializer.java
@@ -20,11 +20,11 @@ package org.apache.hadoop.yarn.server.timelineservice.reader.security;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.http.FilterContainer;
-import org.apache.hadoop.security.AuthenticationWithProxyUserFilter;
+import org.apache.hadoop.security.authentication.server.AuthenticationFilter;
 import org.apache.hadoop.yarn.server.timeline.security.TimelineAuthenticationFilterInitializer;
 
 /**
- * Filter initializer to initialize {@link AuthenticationWithProxyUserFilter}
+ * Filter initializer to initialize {@link AuthenticationFilter}
  * for ATSv2 timeline reader server with timeline service specific
  * configurations.
  */
@@ -32,9 +32,9 @@ public class TimelineReaderAuthenticationFilterInitializer extends
     TimelineAuthenticationFilterInitializer{
 
   /**
-   * Initializes {@link AuthenticationWithProxyUserFilter}
+   * Initializes {@link AuthenticationFilter}
    * <p>
    * Propagates to {@link AuthenticationWithProxyUserFilter} configuration all
    * YARN configuration properties prefixed with
    * {@link TimelineAuthenticationFilterInitializer#PREFIX}.
    *
@@ -47,7 +47,7 @@ public class TimelineReaderAuthenticationFilterInitializer extends
   public void initFilter(FilterContainer container, Configuration conf) {
     setAuthFilterConfig(conf);
     container.addGlobalFilter("Timeline Reader Authentication Filter",
-        AuthenticationWithProxyUserFilter.class.getName(),
+        AuthenticationFilter.class.getName(),
         getFilterConfig());
   }
 }


---------------------------------------------------------------------
@@ -32,9 +32,9 @@ public class TimelineReaderAuthenticationFilterInitializer extends
    * <p>
-   * Propagates to {@link AuthenticationWithProxyUserFilter} configuration all
+   * Propagates to {@link AuthenticationFilter} configuration all
    * YARN configuration properties prefixed with
    * {@link TimelineAuthenticationFilterInitializer#PREFIX}.
To unsubscribe, e-mail: common-commits-unsubscribe@hadoop.apache.org
For additional commands, e-mail: common-commits-help@hadoop.apache.org